Suggest in text how to break out parts as keywords to reduce complexity. Only if
the code contains many similar repetitive calls that are necessary,
add `# robocop:off` comment with explanation.

Consult the specific violation message for the exact length/complexity metric that's exceeded.
